/*
 *  linux/fs/hfs/catalog.c
 *
 *  Copyright (C) 1995  Paul H. Hargrove
 *  This file may be distributed under the terms of the GPL
 *
 */

#include <linux/config.h>
#ifdef MODULE
#include <linux/module.h>
#endif

#include "hfs_fs.h"
#include <linux/kernel.h>
#include <linux/errno.h>
#include <linux/mm.h>
#include <linux/fs.h>

#define CAT_TREE (HFS_SB(sb)->s_cat_tree)

/*======== Public Internal Functions ========*/

/*
 * Given a parent DirID and a name, find the catalog brec
 * return 0 on success, or an error code
 */
int hfs_cat_find(struct super_block *sb, unsigned int parent, int len,
	const char *name, struct hfs_brec ** brec)
{
	struct hfs_rec_key target;

	if (!sb || !brec || (len && !name))
		return -EINVAL;

	if (len > HFS_NAMELEN) {
		/* we'll never find it!! */
		return -ENAMETOOLONG;
	}

	/* target.KeyLen = XXX; */
	target.u.ckr.ParID = to_l(parent);
	target.u.ckr.CName[0] = len;
	memcpy(target.u.ckr.CName+1, name, len);

	return hfs_bfind(CAT_TREE, &target, brec, HFS_BFIND_READ_EQ);
}

/*
 * Given a catalog brec structure, replace it with the count'th next brec.
 * if skip & HFS_SKIP_DIR, then don't return with a directory brec.
 * return an error code if there is a problem, 0 if OK.
 */
int hfs_cat_next(struct hfs_brec **brec, int count, int skip)
{
	int error;

	if (!brec)
		return -EINVAL;

	while (count--) {
		do {
			error = hfs_bsucc(brec);
			if (error)
				return error;
		} while ((skip & HFS_SKIP_DIR) &&
			 (((*brec)->data.raw_inode->cdrType)==HFS_CDR_DIR));
	}
	return 0;
}
