/* 
 * linux/include/linux/hfs_fs_sb.h
 *
 * Copyright (C) 1995 by Paul H. Hargrove
 * This file may be distributed under the terms of the GPL
 *
 * This file defines the type (struct hfs_sb_info) which contains the
 * HFS-specific information in in-core the superblock.
 */

#ifndef _HFS_FS_SB
#define _HFS_FS_SB

/*
 * hfs superblock data in memory
 */
struct hfs_sb_info {
	/* The buffer_head holding the real superblock (aka VIB or MDB) */
	struct buffer_head *	s_sbbh;
	/* The buffer_heads holding the allocation bitmap */
	struct buffer_head *	s_bitmap[16];
	/* A pointer to the data in s_sbbh */
	struct hfs_super *	s_hs;
	/* The number of allocation blocks in the filesystem */
	unsigned short		s_fs_ablocks;
	/* The nuber of unused allocation blocks in the filesystem */
	unsigned short		s_free_ablocks;
	/* The number of 512-byte blocks per "allocation block" */
	unsigned short		s_alloc_blksz;
	/* The first 512-byte disk-block represented in the bitmap */
	unsigned short		s_fs_start;
	/* The next available file id number */
	unsigned int		s_next_id;
	/* The number of bytes to try to allocate when extending a file */
	unsigned int		s_clump_size;
	/* The number of writes in the history of the filesystem */
	/* XXX We don't yet increment this */
     	unsigned int		s_write_count;
	/* The number of regular (non-directory) files in the root directory */
	unsigned short		s_root_files;
	/* The number of directories in the root directory */
	unsigned short		s_root_dirs;
	/* The number of regular files in the filesystem */
	unsigned int		s_file_count;
	/* The number of directories in the filesystem */
	unsigned int		s_dir_count;
	/* Information about the extents b-tree */
	struct hfs_btree *	s_ext_tree;
	/* Information about the catalog b-tree */
	struct hfs_btree *	s_cat_tree;
	/* The uid to assign to all files */
	uid_t			s_uid;
	/* The gid to assign to all files */
	gid_t			s_gid;
	/* The umask applied to the permissions on all files */
	unsigned short		s_umask;
	/* The function used to map Mac filenames to Linux filenames */
	int			(*s_namein) (char *, const unsigned char *);
	/* The function used to Map Linux filenames to Mac filenames */
	int			(*s_nameout) (char *, int, const char *);
};
#endif
