/*
 *  linux/fs/hfs/meta.c
 *
 *  Copyright (C) 1995  Paul H. Hargrove
 *  This file may be distributed under the terms of the GPL
 */

#include <linux/config.h>
#ifdef MODULE
#include <linux/module.h>
#endif

#include "hfs_fs.h"
#include <linux/fs.h>
#include <linux/kernel.h>
#include <linux/errno.h>
#include <asm/segment.h>

static int read_mem(struct inode *inode, struct file *file, char *buf, int count)
{
	unsigned long p = file->f_pos;

	if (count < 0)
		return -EINVAL;
	if (!HFS_I(inode)->u.cap_info.meta) {
		printk("HFS: NULL finderinfo structure\n");
		return -EIO;
	}
	if (p >= inode->i_size)
		return 0;
	if (count > inode->i_size - p)
		count = inode->i_size - p;

	memcpy_tofs(buf, HFS_I(inode)->u.cap_info.meta + p, count);
	file->f_pos += count;
	return count;
}

static struct file_operations hfs_cap_info_operations = {
	NULL,           /* lseek */
	read_mem,
};

struct inode_operations hfs_cap_info_inode_operations = {
	&hfs_cap_info_operations,
};
